<?php declare(strict_types=1);
namespace ArchiveSiteMeta\View\Helper;
use Laminas\View\Helper\AbstractHelper;


//class ArchiveSiteMeta implements FactoryInterface
//{


#use ArchiveSiteMeta\Service\Form\ConfigFormFactory;

/**
 * View helper to get metadata for all pages of the specified type.
 */
class ArchiveSiteMetaViewHelper extends AbstractHelper
{


    public function __construct($omekaSettings)
    {
        $this->omekaSettings = $omekaSettings;
    }
    /**
     * Get data for all pages of the specified type in the current site.
     *
     * @param string|array $pageType
     * @return \Omeka\Api\Representation\SitePageBlockRepresentation[]
     */
    //public function __invoke($pageType)
    public function getSiteMetaValues($site)
    {
        // Check if the site page has the specified block.
        //$site = $this->currentSite();
        $pages = $site->pages();

        foreach ($pages as $page) {
            foreach ($page->blocks() as $block) {
                // A page can belong to multiple types…
                if ($block->layout() === 'archiveSiteMeta') {
                    $url = null;
                    $attachments = $block->attachments();
                    if ($attachments) {
                      $media = $attachments[0]->item()->media()[0];
                      $url = $media->primaryMedia()->thumbnailUrl('large');
                    }
                    return array(
                      "currator" => $block->dataValue('currator'),
                      "thumbnail" => $url,
                      'project_date' => $block->dataValue('project_date'),
                      'collection' => $block->dataValue('collection'),
                    );
                }
            }
        }
        return null;
    }

    public function getCollections($sites){
      $collections = $this->omekaSettings->get('sitemeta_collections');
      $collection_options = [];

      foreach ( explode("\n", $collections) as $value ) {
        $key_value = explode("=", str_replace(array("\r", "\n"), '',$value));
        $collection_options[trim($key_value[1])] = trim($key_value[0]);
      }
      //return $collections;
      //$site = $sites[0]->setting('sitemeta_collections');
      //$collections = [];
      $result = [];
      foreach ($sites as $site) {
        $settings = $this->getSiteMetaValues($site);
        if ($settings && !in_array($settings['collection'], $result)) {
          $name = $collection_options[$settings['collection']];
          $result[$settings['collection']] = $name;
          //array_push($collections, $settings['collection']);
        }
      }
      return $result;
    }

    public function getPages()
    {
        return [];
    }
    /**
     * Get the page's meta image url.
     *
     * @param SitePageRepresentation
     * @return string media url
     */
    public function getPageImage($page)
    {
        foreach ($page->blocks() as $block) {
            if ($block->layout() === 'archiveSiteMeta') {
              $attachments = $block->attachments();
              if (!$attachments) {
                  return null;
              }
              $media = $attachments[0]->item()->media()[0];
              return $media->primaryMedia()->thumbnailUrl('large');
            }
        }
        return null;
    }

    /**
     * @return \Omeka\Api\Representation\SiteRepresentation
     */
    protected function currentSite()
    {
        $view = $this->getView();
        return isset($view->site)
            ? $view->site
            : $view->getHelperPluginManager()->get('Laminas\View\Helper\ViewModel')->getRoot()->getVariable('site');
    }
}
